"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const request = require("request-promise-native");
const rimraf = require("rimraf");
const querystring = require("querystring");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages("sfpowerkit", "org_coverage");
class OrgCoverage extends command_1.SfdxCommand {
    async run() {
        rimraf.sync("temp_sfpowerkit");
        await this.org.refreshAuth();
        const conn = this.org.getConnection();
        this.flags.apiversion =
            this.flags.apiversion || (await conn.retrieveMaxApiVersion());
        var apexcoverage = new ApexCoverage();
        apexcoverage.coverage = await this.getApexCoverage(conn);
        if (this.flags.outputfile) {
            await fs.outputJSON(this.flags.outputfile, apexcoverage);
        }
        this.ux.log(`Successfully Retrieved the Apex Test Coverage of the org ${this.org.getOrgId()} `);
        this.ux.log(`coverage:${apexcoverage.coverage}`);
        return { coverage: apexcoverage.coverage };
    }
    async getApexCoverage(conn) {
        var encoded_querystring = querystring.escape(`SELECT PercentCovered FROM ApexOrgWideCoverage`);
        var query_uri = `${conn.instanceUrl}/services/data/v${this.flags.apiversion}/tooling/query?q=${encoded_querystring}`;
        //this.ux.log(`Query URI ${query_uri}`);
        const coverage_score_query_result = await request({
            method: "get",
            url: query_uri,
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            },
            json: true
        });
        // this.ux.logJson(health_score_query_result);
        return coverage_score_query_result.records[0].PercentCovered;
    }
}
OrgCoverage.description = messages.getMessage("commandDescription");
OrgCoverage.examples = [
    `$ sfdx sfpowerkit:org:orgcoverage  -u myOrg@example.com
  Successfully Retrieved the Apex Test Coverage of the org XXXX
  coverage:85
  `
];
// Comment this out if your command does not require an org username
OrgCoverage.requiresUsername = true;
exports.default = OrgCoverage;
class ApexCoverage {
}
exports.ApexCoverage = ApexCoverage;
//# sourceMappingURL=orgcoverage.js.map