"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const baseMetadataRetriever_1 = __importDefault(require("./baseMetadataRetriever"));
const metadataInfo_1 = require("../metadataInfo");
const metadataFiles_1 = __importDefault(require("../metadataFiles"));
const QUERY = "SELECT DurableId, DeveloperName, QualifiedApiName, NamespacePrefix FROM EntityDefinition order by QualifiedApiName";
class EntityDefinitionRetriever extends baseMetadataRetriever_1.default {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!EntityDefinitionRetriever.instance) {
            EntityDefinitionRetriever.instance = new EntityDefinitionRetriever(org);
        }
        return EntityDefinitionRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            super.setQuery(QUERY);
            let entities = await super.getObjects();
            this.data = entities;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getEntityDefinitions() {
        return await this.getObjects();
    }
    async getObjectNameByDurableId(durableId) {
        let objectName = "";
        let entities = await this.getEntityDefinitions();
        for (var i = 0; i < entities.length; i++) {
            let entity = entities[i];
            if (entity.DurableId === durableId) {
                objectName = entity.QualifiedApiName;
                break;
            }
        }
        return objectName;
    }
    async getDurableIdByObjectName(objectName) {
        let durableId = "";
        let found = false;
        let entities = await this.getEntityDefinitions();
        for (var i = 0; i < entities.length; i++) {
            let entity = entities[i];
            if (entity.QualifiedApiName === objectName) {
                durableId = entity.DurableId;
                found = true;
                break;
            }
        }
        if (!found) {
            //fetch the objectName from server and add it to the entity list
            let entity = {
                Id: "",
                QualifiedApiName: objectName
            };
            this.data.push(entity);
        }
        return durableId;
    }
    async getObjectForPermission() {
        if (this.objectForPermission && this.objectForPermission.length > 0) {
            return this.objectForPermission;
        }
        this.objectForPermission = [];
        await this.org.refreshAuth();
        let res = await this.org
            .getConnection()
            .query("SELECT SobjectType, count(Id) From ObjectPermissions Group By sObjectType");
        if (res !== undefined) {
            this.objectForPermission = res.records.map(elem => {
                return elem["SobjectType"];
            });
        }
        if (!this.objectForPermission.includes("PersonAccount")) {
            this.objectForPermission.push("PersonAccount");
        }
        return this.objectForPermission;
    }
    async existObjectPermission(object) {
        let found = false;
        //Look first in project files
        if (!lodash_1.default.isNil(metadataInfo_1.METADATA_INFO.CustomObject.components)) {
            found = metadataInfo_1.METADATA_INFO.CustomObject.components.includes(object);
        }
        if (!found && !metadataFiles_1.default.sourceOnly) {
            //not found, check on the org
            let objects = await this.getObjectForPermission();
            found = objects.includes(object);
        }
        return found;
    }
}
exports.default = EntityDefinitionRetriever;
//# sourceMappingURL=entityDefinitionRetriever.js.map