"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const baseMetadataRetriever_1 = __importDefault(require("./baseMetadataRetriever"));
const entityDefinitionRetriever_1 = __importDefault(require("./entityDefinitionRetriever"));
const metadataInfo_1 = require("../metadataInfo");
const metadataFiles_1 = __importDefault(require("../metadataFiles"));
const QUERY = "SELECT Id, QualifiedApiName, EntityDefinitionId, DeveloperName, NamespacePrefix FROM FieldDefinition ";
class FieldRetriever extends baseMetadataRetriever_1.default {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!FieldRetriever.instance) {
            FieldRetriever.instance = new FieldRetriever(org);
        }
        return FieldRetriever.instance;
    }
    async getObjects() {
        let fieldsToReturn = [];
        if (!this.data && !this.dataLoaded) {
            let entityDefinitionUtils = entityDefinitionRetriever_1.default.getInstance(this.org);
            let objects = await entityDefinitionUtils.getObjectForPermission();
            this.data = {};
            for (let i = 0; i < objects.length; i++) {
                let objectName = objects[i];
                let durableId = await entityDefinitionUtils.getDurableIdByObjectName(objectName);
                super.setQuery(QUERY + " WHERE EntityDefinitionId ='" + durableId + "'");
                let fields = await super.getObjects();
                fields = fields.map(field => {
                    field.SobjectType = objectName;
                    field.FullName = objectName + "." + field.QualifiedApiName;
                    return field;
                });
                this.data[objectName] = fields;
                fieldsToReturn.push(...fields);
            }
            this.dataLoaded = true;
        }
        else {
            if (this.data) {
                Object.keys(this.data).forEach(key => {
                    fieldsToReturn.push(...this.data[key]);
                });
            }
        }
        return fieldsToReturn;
    }
    async getFields() {
        return await this.getObjects();
    }
    async getFieldsByObjectName(objectName) {
        if (!this.data) {
            await this.getObjects();
        }
        if (!this.data[objectName]) {
            let entityDefinitionUtils = entityDefinitionRetriever_1.default.getInstance(this.org);
            let fields = [];
            let durableId = await entityDefinitionUtils.getDurableIdByObjectName(objectName);
            if (durableId !== undefined && durableId !== "") {
                super.setQuery(QUERY + " WHERE EntityDefinitionId ='" + durableId + "'");
                fields = await super.getObjects();
                fields = fields.map(field => {
                    field.SobjectType = objectName;
                    field.FullName = objectName + "." + field.QualifiedApiName;
                    return field;
                });
            }
            this.data[objectName] = fields;
        }
        return this.data[objectName];
    }
    async fieldExist(fullName) {
        let found = false;
        let fieldParts = fullName.split(".");
        if (fieldParts.length !== 2) {
            return false;
        }
        //Look first in project files
        if (!lodash_1.default.isNil(metadataInfo_1.METADATA_INFO.CustomField.components)) {
            found = metadataInfo_1.METADATA_INFO.CustomField.components.includes(fullName);
        }
        if (!found && !metadataFiles_1.default.sourceOnly) {
            //not found, check on the org
            let objectName = fieldParts[0];
            let fieldDefinitions = await this.getFieldsByObjectName(objectName);
            let field = fieldDefinitions.find(field => field.FullName === fullName);
            found = field !== undefined;
        }
        return found;
    }
}
exports.default = FieldRetriever;
//# sourceMappingURL=fieldRetriever.js.map